ImeActionMapper class

Constructors

ImeActionMapper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

imeActionMap Map<String, TextInputAction>
final

Static Methods

initialize() → void
isImeAction(String keyString) bool
Checks if the keyString represents an IME action.
toImeAction(String keyString) TextInputAction?
Converts a keyString to an IME action ID.