RanorexSupportedClassName class

Constructors

RanorexSupportedClassName()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

actionChip → const String
alertDialog → const String
appBar → const String
badge → const String
bottomNavigationBar → const String
bottomSheet → const String
buttonBar → const String
calendarDatePicker → const String
card → const String
carouselView → const String
checkbox → const String
checkboxListTile → const String
chip → const String
choiceChip → const String
circularProgressIndicator → const String
column → const String
container → const String
dataTable → const String
datePicker → const String
dialog → const String
divider → const String
drawer → const String
drawerHeader → const String
editableText → const String
elevatedButton → const String
filterChip → const String
floatingActionButton → const String
gridTile → const String
gridTileBar → const String
gridView → const String
icon → const String
iconButton → const String
image → const String
inkwell → const String
inputChip → const String
linearProgressIndicator → const String
listTile → const String
listView → const String
materialButton → const String
overflowBar → const String
popupMenuButton → const String
popupMenuDivider → const String
radio → const String
radioListTile → const String
row → const String
scaffold → const String
segmentedButton → const String
singleChildScrollView → const String
slider → const String
snackBar → const String
stack → const String
switchButton → const String
tabBar → const String
table → const String
textButton → const String
textField → const String
textFormField → const String
textWidget → const String
timePicker → const String
toggleButton → const String
tooltip → const String